@@ -4,14 +4,14 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.001002'; # VERSION
+our $VERSION = '1.001003'; # VERSION
 
 use parent 'Exporter';
 use Test::Builder;
 use version 0.86 qw( is_lax is_strict );
 use File::Find::Rule::Perl;
-use Module::Extract::VERSION;
 use Test::More;
+use Module::Metadata;
 
 our @EXPORT = qw( version_all_ok ); ## no critic (Modules::ProhibitAutomaticExportation)
 our @EXPORT_OK = qw( version_ok );
@@ -42,8 +42,9 @@ $cfg->{has_version}
 
 sub _get_version {
 	my $pm = shift;
-	return my $version
-		= Module::Extract::VERSION->parse_version_safely( $pm );
+
+	my $info = Module::Metadata->new_from_file( $pm );
+	return $info->version;
 }
 
 sub version_ok {
@@ -130,7 +131,7 @@ Test::Version - Check to see that version's in modules are sane
 
 =head1 VERSION
 
-version 1.001002
+version 1.001003
 
 =head1 SYNOPSIS
 
